AMCClient class

修改: 1、修改api为"/api/user/v1.0/login.cgi" 2、添加新方法NetworkConfig.setRemoteId(remoteId); 把id拼接到域名里进行拼接

Constructors

AMCClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

get({String? deviceIp, required String apiPath, Map<String, dynamic>? pathParams, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers}) Future<Result>
login(String remoteId, String account, String password) Future<Result>
logout() Future<Result>
post({String? deviceIp, required String apiPath, Map<String, dynamic>? pathParams, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers}) Future<Result>