AMCDeviceClient class

Constructors

AMCDeviceClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFinalIp(String? deviceIp) Future<String?>
get({String? deviceIp, required String apiPath, Map<String, dynamic>? bodyParams, Map<String, dynamic>? pathParams, Map<String, dynamic>? headers}) Future<Result>
login(NASDeviceInfo info, String userName, String password) Future<Result>
logout() Future<Result>
post({String? deviceIp, required String apiPath, Map<String, dynamic>? bodyParams, Map<String, dynamic>? pathParams, Map<String, dynamic>? headers}) Future<Result>
smsRequest(String mobile) Future<bool>