ClientDeviceRequest class

Inheritance

Constructors

ClientDeviceRequest()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createFinalHeader(Map<String, dynamic>? header) Future<Map<String, dynamic>>
inherited
get(String? deviceIp, String apiPath, Map<String, dynamic>? pathParams, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future<Result>
inherited
getDefaultPath() Future<String>
override
getDeviceIMEI() → void
inherited
getResponse(bool isPost, String fullPath, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future
inherited
isResponseSuccess(Map<String, dynamic> rawResponse) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String? deviceIp, String apiPath, Map<String, dynamic>? pathParams, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future<Result>
inherited
rebuildUrl(String? deviceIp, String apiPath, Map<String, dynamic>? pathParams) Future<String>
inherited
refreshToken(String? deviceIp) Future<bool>
override
request(String? deviceIp, String fullPath, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers, bool isPost) Future<Result>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited