ClientRequest class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
-
get(String? deviceIp, String apiPath, Map<String, dynamic>? pathParams, Map<String, dynamic>? bodyParams, )
→ Future<Result>
-
-
getDefaultPath()
→ Future<String>
-
-
getDeviceIMEI()
→ void
-
-
getResponse(bool isPost, String fullPath, Map<String, dynamic>? bodyParams, )
→ Future
-
-
isResponseSuccess(Map<String, dynamic> rawResponse)
→ bool
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
post(String? deviceIp, String apiPath, Map<String, dynamic>? pathParams, Map<String, dynamic>? bodyParams, )
→ Future<Result>
-
-
rebuildUrl(String? deviceIp, String apiPath, Map<String, dynamic>? pathParams)
→ Future<String>
-
-
refreshToken(String? deviceIp)
→ Future<bool>
-
-
request(String? deviceIp, String fullPath, Map<String, dynamic>? bodyParams, bool isPost)
→ Future<Result>
-
-
toString()
→ String
-
A string representation of this object.
inherited