DioClient class

Implemented types

Constructors

DioClient()

Properties

dio → Dio
对外获取 Dio 实例的接口 如果为空会先初始化
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String url, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited