HttpClient class abstract

Implementers

Constructors

HttpClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String url, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String url, Map<String, dynamic>? bodyParams, Map<String, dynamic>? headers) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited