ErrorCode enum

Inheritance
Available extensions

Values

dataParseError → const ErrorCode
const ErrorCode("-101", "数据解析错误")
networkTimeout → const ErrorCode
const ErrorCode("-201", "网络请求超时")
invalidToken → const ErrorCode
const ErrorCode("-301", "无效的身份令牌")
serverError → const ErrorCode
const ErrorCode("-500", "服务器内部错误")
unknownError → const ErrorCode
const ErrorCode("-999", "未知错误")
refreshTokenError → const ErrorCode
const ErrorCode("-401", "刷新令牌失败")

Properties

code String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logError({dynamic extraData}) → void

Available on ErrorCode, provided by the ErrorCodeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCode(String code) ErrorCode?

Constants

values → const List<ErrorCode>
A constant List of the values in this enum, in order of their declaration.