APPDeviceUtils class

NAS 设备相关工具类

Constructors

APPDeviceUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceInfo() Map<String, dynamic>
获取详细的设备信息
getDeviceTypeName() String
获取设备类型名称
isBrowser() bool
isComputer() bool
便捷的设备类型判断方法
isMobileDevice() bool
是否为移动设备(手机或平板)
isOther() bool
isPhone() bool
isTablet() bool
isTouchDevice() bool
是否为触摸设备
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getDeviceType() int
获取当前设备类型 返回值: 1-电脑, 2-手机, 3-平板, 4-浏览器, 5-其他
getOrCreateDeviceId() Future<String>