PlatformUtils class

Constructors

PlatformUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printDeviceInfo() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getDeviceId() Future<String?>
getDeviceInfo() Future<String?>
getPlatformName() String
获取平台名称字符串
getPlatformType() PlatformType
获取当前平台类型
isDesktop() bool
判断是否为桌面端
isMobile() bool
判断是否为移动端
isWeb() bool
判断是否为Web端