DataChannelObserverImpl class

Implemented types

Constructors

DataChannelObserverImpl(WebrtcManager state, WebrtcConnection connection)

Properties

connection WebrtcConnection
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state WebrtcManager
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onBufferedAmountChange(int amount) → void
override
onMessage(RTCDataChannelMessage message) → void
override
onStateChange() → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited