LoggerStatistics class

日志统计信息

Constructors

LoggerStatistics({required int totalEvents, required int eventsToday, required Map<LogEventType, int> eventsByType, required double avgEventsPerSecond, required int queueLength, required double memoryUsage, required int totalFileSize})
const

Properties

avgEventsPerSecond double
final
eventsByType Map<LogEventType, int>
final
eventsToday int
final
hashCode int
The hash code for this object.
no setterinherited
memoryUsage double
final
queueLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalEvents int
final
totalFileSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited