LoggerExtension class abstract

日志扩展基类 (简化版本)

Implementers

Constructors

LoggerExtension(String name)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
销毁扩展
initialize(LoggerEngine engine) Future<void>
初始化扩展
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited