PageLifecycleInfo class

页面生命周期信息

Constructors

PageLifecycleInfo({required Route route, required DateTime enterTime, DateTime? exitTime, Duration? stayDuration})

Properties

currentStayDuration Duration
no setter
enterTime DateTime
final
exitTime DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isActive bool
no setter
route Route
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stayDuration Duration?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited