ApiCompleteEvent class

API完整事件 - 合并请求和响应

Inheritance

Constructors

ApiCompleteEvent({required String method, required String url, required String requestId, required Duration duration, required String sessionId, int? statusCode, Map<String, String>? tokens, dynamic requestBody, dynamic responseData, String? errorMessage, DateTime? timestamp})

Properties

duration Duration
final
errorMessage String?
final
eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
final
metadata Map<String, dynamic>
finalinherited
method String
final
requestBody → dynamic
final
requestId String
final
responseData → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
finalinherited
statusCode int?
final
timestamp DateTime
finalinherited
tokens Map<String, String>?
final
type LogEventType
finalinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited