ButtonClickEvent class

按钮点击事件

Inheritance

Constructors

ButtonClickEvent({required String eventName, required String buttonText, required String currentPage, required Map<String, dynamic> parameters, required String widgetType, required String sessionId, String? widgetKey, Map<String, dynamic>? position, DateTime? timestamp})

Properties

buttonText String
final
currentPage String
final
eventId String
finalinherited
eventName String
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
parameters Map<String, dynamic>
final
position Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
finalinherited
timestamp DateTime
finalinherited
type LogEventType
finalinherited
widgetKey String?
final
widgetType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited