CustomEvent class
自定义事件
Constructors
Properties
- category → String
-
final
- description → String?
-
final
- eventId → String
-
finalinherited
- eventName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
finalinherited
-
parameters
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
finalinherited
- timestamp → DateTime
-
finalinherited
- type → LogEventType
-
finalinherited
- value → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
转换为JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited