LogEvent class abstract

抽象日志事件基类

Implementers

Constructors

LogEvent({required String eventId, required DateTime timestamp, required LogEventType type, required String sessionId, Map<String, dynamic> metadata = const {}})

Properties

eventId String
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
timestamp DateTime
final
type LogEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateEventId() String
生成事件ID