LogFileHeader class

日志文件头信息

Constructors

LogFileHeader({required String version, required String date, required String deviceId, required String userId, required String appVersion, required String platform, required String deviceModel, required String osVersion, required DateTime createdAt, required int eventCount})
const
LogFileHeader.fromJson(Map<String, dynamic> json)
factory

Properties

appVersion String
final
createdAt DateTime
final
date String
final
deviceId String
final
deviceModel String
final
eventCount int
final
hashCode int
The hash code for this object.
no setterinherited
osVersion String
final
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited