NativeCrashEvent class

原生崩溃事件

Inheritance

Constructors

NativeCrashEvent({required String crashType, required String platform, required String errorMessage, required String stackTrace, required Map<String, dynamic> deviceInfo, required Map<String, dynamic> appInfo, required Map<String, dynamic> memoryInfo, required Map<String, dynamic> threadInfo, required String sessionId, String severity = 'critical', DateTime? timestamp})
NativeCrashEvent.fromNativeData(Map<String, dynamic> data, String sessionId)
创建系统崩溃事件的工厂方法
factory

Properties

appInfo Map<String, dynamic>
final
crashType String
final
crashTypeDescription String
获取可读的崩溃类型描述
no setter
deviceInfo Map<String, dynamic>
final
errorMessage String
final
eventId String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isFatal bool
是否为致命错误
no setter
memoryInfo Map<String, dynamic>
final
metadata Map<String, dynamic>
finalinherited
platform String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
finalinherited
severity String
final
stackTrace String
final
threadInfo Map<String, dynamic>
final
timestamp DateTime
finalinherited
type LogEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited