PageNavigationEvent class

页面跳转事件

Inheritance

Constructors

Properties

arguments Map<String, dynamic>?
final
eventId String
finalinherited
fromPage String
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
finalinherited
final
routeName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
finalinherited
stayDuration Duration?
final
timestamp DateTime
finalinherited
toPage String
final
type LogEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited