SystemEvent class

系统事件

Inheritance

Constructors

SystemEvent({required String eventName, required String sessionId, Map<String, dynamic> systemInfo = const {}, String? level = 'info', String? source, DateTime? timestamp})

Properties

eventId String
finalinherited
eventName String
final
hashCode int
The hash code for this object.
no setterinherited
level String?
final
metadata Map<String, dynamic>
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
finalinherited
source String?
final
systemInfo Map<String, dynamic>
final
timestamp DateTime
finalinherited
type LogEventType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
转换为JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited