LogFormatter class

日志格式化器 - 将日志转换为易读的格式

Constructors

LogFormatter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

createFileHeader({required String deviceId, required String userId, required String version}) String
创建日志文件头 (已移除,不再需要)
formatEvent(LogEvent event, {bool pretty = true}) String
格式化单个日志事件为易读格式
formatEvents(List<LogEvent> events, {bool pretty = true}) String
格式化多个事件