WidgetHelper class

Widget辅助工具类 (简化版本)

Constructors

WidgetHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractButtonText(Widget widget) String
提取按钮文本
extractContextParameters(BuildContext? context) Map<String, dynamic>
提取上下文参数
getCurrentPageName(BuildContext? context) String
获取当前页面名称
hasClickHandler(Widget widget) bool
检查Widget是否有点击处理器
isClickableWidget(Widget widget) bool
检查是否为可点击的Widget