NavigationLogUtils class

导航日志工具类

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

cleanPageName(String pageName) String
清理页面名称
formatStayDuration(int? milliseconds) String
计算停留时长的可读格式
formatTimestamp(int timestamp) String
格式化时间戳
isValidPageName(String? pageName) bool
验证页面名称是否有效