NavigationLogger class

专门的导航日志管理器 统一处理所有导航相关的日志记录和格式化

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
会话ID,应用启动时生成
final

Methods

clearLogs() → void
清空导航日志
exportRecentLogs({int? limit}) List<Map<String, dynamic>>
导出最近的导航日志
getNavigationFlow() Map<String, dynamic>
获取导航流程分析
getNavigationStats() Map<String, dynamic>
获取导航日志统计
logContainerAction({required String action, required String fromPage, bool forceFinish = false, Map<String, dynamic>? params, Map<String, dynamic>? metadata}) → void
记录容器操作(关闭/强制关闭)
logFlutterNavigation({required String action, required String fromPage, required String toPage, Map<String, dynamic>? params, Map<String, dynamic>? metadata, Duration? stayDuration}) → void
记录Flutter页面导航
logNativeNavigation({required String action, required String fromPage, required String toPage, Map<String, dynamic>? params, Map<String, dynamic>? metadata, bool hasFunction = false}) → void
记录原生页面导航
logStackOperation({required String action, String? fromPage, String? toPage, List<String>? stackPages, Map<String, dynamic>? metadata}) → void
记录路由栈操作
logWebViewNavigation({required String action, required String fromPage, required String url, Map<String, dynamic>? permissions, Map<String, dynamic>? metadata}) → void
记录WebView导航
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchLogs({String? action, String? navigationType, String? fromPage, String? toPage, DateTime? startTime, DateTime? endTime}) List<Map<String, dynamic>>
搜索导航日志
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NavigationLogger
no setter

Constants

maxLogCount → const int
最大保存的日志数量