RouteInfo class

路由信息

Constructors

RouteInfo({required String pageName, required String routeAddress, required Map<String, dynamic> params, required DateTime timestamp, bool isTransparent = false, bool isFullDialog = false, required String navigationId, required int stackDepth})

Properties

hashCode int
The hash code for this object.
no setterinherited
isFullDialog bool
final
isSystemBack bool
getter/setter pair
isTransparent bool
final
final
pageName String
final
params Map<String, dynamic>
final
routeAddress String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackDepth int
final
stayDuration Duration?
getter/setter pair
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited