IUnifiedRouter class abstract

统一路由接口

Constructors

IUnifiedRouter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildWidgetByPageName(String pageName, [dynamic params]) Widget?
finishContainer({Map<String, dynamic>? params, bool forceFinish}) → void
getGeneralInfo() Future<Map>
getSubmoduleConfig() Future<Map>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFlutterPage(String pageName, {Map<String, dynamic>? params, dynamic function(dynamic funParam)?, bool transparentRoute, bool fullscreenDialog, bool needClearStack, bool needCloseCurrent}) Future?
openNativePage(String pageName, {Map<String, dynamic>? params, dynamic function(dynamic funParam)?}) → void
openNativeWebView(String url, {bool cameraPermission = false, bool photoPermission = false, WebViewRightButton? webViewRightButton}) → void
registerEvent(String url, dynamic handler(dynamic info)) → void
registerPage(String url, Widget page(dynamic info)) → void
removeEvent(String url) → void
sendEventToFlutter(String eventName, {Map<String, dynamic>? params, dynamic function(dynamic funParam)?}) → void
sendEventToNative(String eventName, {Map<String, dynamic>? params, dynamic function(dynamic funParam)?}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited