NavigationBuildStats class
导航性能统计
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getStats(
) → Map< String, dynamic> -
recordCacheHit(
String pageName) → void -
recordCacheMiss(
String pageName) → void -
recordPageBuild(
String pageName, Duration buildTime) → void -
reset(
) → void