NavigationStats class

导航统计

Constructors

Properties

activeRoutes int
final
averageStayTime Duration
final
hashCode int
The hash code for this object.
no setterinherited
lifecycles List<Map<String, dynamic>>
final
queuedEvents int
final
routeFrequency Map<String, int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalRoutes int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited