PerformanceReport class

性能报告

Constructors

PerformanceReport({required List<String> slowRoutes, required List<String> fastRoutes, required Map<String, Duration> performanceData, required DateTime generatedAt})

Properties

fastRoutes List<String>
final
generatedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
performanceData Map<String, Duration>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slowRoutes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited