RouteLifecycleInfo class

路由生命周期信息

Constructors

RouteLifecycleInfo({required Route route, required String pageName, DateTime? enterTime, DateTime? exitTime, Duration? stayDuration, DateTime? loadStartTime, Duration? loadTime})

Properties

enterTime DateTime?
getter/setter pair
exitTime DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loadStartTime DateTime?
getter/setter pair
loadTime Duration?
getter/setter pair
pageName String
final
route Route
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stayDuration Duration?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited