UnifiedNavigationInterceptor class

统一导航拦截器

Inheritance

Properties

batchLogging bool
no setter
enableCacheIntegration bool
no setter
enablePerformanceTracking bool
no setter
hashCode int
The hash code for this object.
no setterinherited
The navigator that the observer is observing, if any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeTop(Route topRoute, Route? previousTopRoute) → void
The top most route has changed.
inherited
didPop(Route route, Route? previousRoute) → void
The Navigator popped route.
override
didPush(Route route, Route? previousRoute) → void
The Navigator pushed route.
override
didRemove(Route route, Route? previousRoute) → void
The Navigator removed route.
override
didReplace({Route? newRoute, Route? oldRoute}) → void
The Navigator replaced oldRoute with newRoute.
override
didStartUserGesture(Route route, Route? previousRoute) → void
The Navigator's routes are being moved by a user gesture.
inherited
didStopUserGesture() → void
User gesture is no longer controlling the Navigator.
inherited
dispose() → void
销毁拦截器
getNavigationStats() NavigationStats
获取导航统计
getPerformanceReport() PerformanceReport
获取路由性能报告
logCustomNavigation({required String toPageName, String? fromPageName, required String navigationType, Map<String, dynamic>? params, Duration? stayDuration}) → void
记录自定义导航事件
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetStats() → void
重置统计信息
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited