UnifiedNavigationSystem class
统一路由导航系统
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → UnifiedNavigationSystem
-
no setter
Static Methods
-
addRouteChangeListener(
dynamic listener(RouteInfo? current, RouteInfo? previous)) → void - 添加路由变化监听器
-
buildWidgetByPageName(
String pageName, [dynamic params]) → Widget? - 构建页面Widget
- 检查是否可以返回
-
clearStack(
) → void - 清空路由栈
- 创建新的导航观察者实例(用于容器内部的 Navigator)
-
dispose(
) → void - 释放资源
- 导出导航历史
-
findPageInStack(
String pageName) → int - 查找特定页面在栈中的位置
-
finishContainer(
{Map< String, dynamic> ? params, bool forceFinish = false}) → void - 关闭容器
-
getCurrentBuildingPageName(
) → String? - 获取当前页面名称
-
getCurrentPageName(
) → String? - 获取当前页面名称
-
getCurrentParams(
) → Map< String, dynamic> ? - 获取当前页面参数
-
getCurrentRouteAddress(
) → String? - 获取当前路由地址
-
getCurrentRouteInfo(
) → RouteInfo? - 获取当前完整路由信息
-
getDiagnostics(
) → Map< String, dynamic> - 获取诊断信息
-
getFullRoutePath(
) → List< String> - 获取完整路由路径
-
getGeneralInfo(
) → Future< Map> - 获取通用信息
- 获取导航路径
- 获取导航统计
- 获取导航观察者
-
getPageTrackingStats(
) → NavigationStatistics - 获取页面跟踪统计
-
getPerformanceReport(
) → Map< String, dynamic> ? - 获取性能报告
-
getPreviousRoute(
) → RouteInfo? - 获取前一个页面信息
-
getRegisteredPages(
) → List< String> - 调试:列出所有注册的页面
-
getRouteStack(
) → List< RouteInfo> - 获取路由栈信息
-
getSubmoduleConfig(
) → Future< Map> - 获取子模块配置
-
healthCheck(
) → bool - 健康检查
-
initializeInterceptor(
{required LoggerEngine loggerEngine, bool batchLogging = true, bool enablePerformanceTracking = true, bool enableCacheIntegration = true}) → void - 初始化导航拦截器
-
initRouter(
IUnifiedRouter router) → void - 初始化路由系统
- 记录自定义导航事件
-
markNextPopAsSystemBack(
) → void - 标记下一次返回为系统返回
-
openFlutterPage(
String pageName, {Map< String, dynamic> ? params, dynamic function(dynamic funParam)?, bool transparentRoute = false, bool fullscreenDialog = false, bool needClearStack = false, bool needCloseCurrent = false}) → Future? - 打开Flutter页面
-
openNativePage(
String pageName, {Map< String, dynamic> ? params, dynamic function(dynamic funParam)?}) → void - 打开原生页面
-
openNativeWebView(
String url, {bool cameraPermission = false, bool photoPermission = false, WebViewRightButton? webViewRightButton}) → void - 打开原生WebView
-
popRoute(
{bool isSystemBack = false}) → void - 记录路由返回
-
pushRoute(
String pageName, Map< String, dynamic> ? params, {String? routeAddress, bool isTransparent = false, bool isFullDialog = false}) → void - 记录新的路由导航
-
registerEvent(
String url, dynamic handler(dynamic info)) → void - 注册事件处理器
-
registerPage(
String url, Widget page(dynamic info)) → void - 注册页面构建器
-
removeEvent(
String url) → void - 移除事件处理器
-
removeRouteChangeListener(
dynamic listener(RouteInfo? current, RouteInfo? previous)) → void - 移除路由变化监听器
-
replaceRoute(
String pageName, Map< String, dynamic> ? params, {String? routeAddress, bool isTransparent = false, bool isFullDialog = false}) → void - 替换当前路由
-
resetStatistics(
) → void - 重置统计信息
-
sendEventToFlutter(
String eventName, {Map< String, dynamic> ? params, dynamic function(dynamic funParam)?}) → void - 发送事件到Flutter
-
sendEventToNative(
String eventName, {Map< String, dynamic> ? params, dynamic function(dynamic funParam)?}) → void - 发送事件到原生
-
setGeneralInfo(
Map< String, dynamic> info) → void - 设置通用信息