WebViewRightButton class

WebView 按钮配置

Constructors

WebViewRightButton({String? rightButtonText, String? rightButtonUrl, String? rightButtonAction})

Properties

hashCode int
The hash code for this object.
no setterinherited
rightButtonAction String?
getter/setter pair
rightButtonText String?
getter/setter pair
rightButtonUrl String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited