NasDeviceConfig class

Constructors

NasDeviceConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOrCreateDeviceId() Future<String>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentNasDeviceSync NASDeviceInfo?
同步获取当前NAS设备信息(可能返回null如果还未初始化)
no setter
defaultAddress String
getter/setter pair

Static Methods

clearCurrentNasInfo() Future<void>
清除保存的NAS设备信息
getCurrentNasDevice() Future<NASDeviceInfo>
获取当前NAS设备信息,首次访问时自动从本地存储加载
init() Future<void>
初始化方法(可选调用,用于预加载) 如果不调用,会在首次使用时自动初始化
setCurrentNasInfo(NASDeviceInfo? info) Future<void>
设置当前NAS设备信息并持久化 当info为null时,不保存到本地存储,保持原有值不变