NASDeviceInfo class

Constructors

NASDeviceInfo({required String serviceName, required String serviceType, required String sn, String? target, required int port, required String ipAddress, String? macAddress, String? remoteId, required Map<String, String> txtRecords})
NASDeviceInfo.fromMap(Map<String, dynamic> map)
从Map创建实例,用于反序列化
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
ipAddress String
final
macAddress String?
final
port int
final
remoteId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
final
serviceType String
final
sn String
final
target String?
final
txtRecords Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
转换为Map,用于序列化
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited