NasDeviceScanner class

mDNS设备扫描器

Constructors

NasDeviceScanner()

Properties

currentRetryCount int
获取当前重试次数
no setter
hashCode int
The hash code for this object.
no setterinherited
isScanning bool
获取当前扫描状态
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanAllDevices({int timeout = 30, bool includeAllServices = true}) Future<List<NASDeviceInfo>>
scanForAomucDevices({int timeout = 20, int retryCount = 2}) Future<List<NASDeviceInfo>>
start(dynamic callback(List<NASDeviceInfo>), {int timeout = 30}) Future<void>
stop() Future<void>
停止扫描
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

DETAIL_QUERY_TIMEOUT int
no setter
INSTANCE_QUERY_TIMEOUT int
no setter
maxRetryCount int
获取最大重试次数
no setter
SERVICE_QUERY_TIMEOUT int
no setter

Constants

MAX_RETRY_COUNT → const int
RETRY_DELAY_SECONDS → const int