DeviceRequestManager class

Constructors

DeviceRequestManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

tokenUpdateStream Stream<TokenUpdateEvent>
获取 token 更新事件流,调用方可以监听此流来获取 token 更新通知
no setter

Static Methods

dispose() → void
释放资源(如果需要的话)
getAccessToken() Future<String>
getP2PToken() Future<String>
getRefreshToken() Future<String>
resetToken() → void
resetTokenFromDeviceData(Map<String, dynamic>? data) → void
saveP2PToken(dynamic token) → void
saveToken(String atoken, String rToken) → void