GlobalTokenUpdateService class

全局单例服务示例

Constructors

GlobalTokenUpdateService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
销毁服务
initialize() → void
初始化服务
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCallback(dynamic callback(String accessToken, String refreshToken)) → void
注册 token 更新回调
toString() String
A string representation of this object.
inherited
unregisterCallback(dynamic callback(String accessToken, String refreshToken)) → void
取消注册回调

Operators

operator ==(Object other) bool
The equality operator.
inherited