TokenUpdateService class

在应用的其他地方使用 token 更新监听的示例

Constructors

TokenUpdateService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startListening() → void
开始监听 token 更新
stopListening() → void
停止监听
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited