RtcData class

RTC数据封装类,对应Android的RtcData.java

Constructors

RtcData({required int cmdType, required Uint8List data})

Properties

cmdType int
getter/setter pair
data Uint8List
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
magic int
getter/setter pair
reserved Uint8List
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
getter/setter pair
version int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
序列化为字节数组
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deserialize(Uint8List bytes) RtcData
从字节数组反序列化

Constants

CMD_TYPE_TEST → const int
HEADER_SIZE → const int
MAGIC → const int
VERSION → const int