IControlMessageHandler class abstract
IControlMessageHandler - 控制消息处理接口 负责管理 WebRTC 控制消息的发送和接收 使用 requestId + apiUrl 标识请求
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
receiveMessage(
WebRtcHttpMessage message) → void -
接收到控制消息(由 DataChannelObserver 调用)
message接收到的消息 -
sendMessage(
WebRtcHttpMessage message, OnReceiveMessageCallback? callback) → void -
发送控制消息
message要发送的消息callback接收响应的回调 -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited