SignalingClient class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onDeviceId ↔ dynamic Function(String)?
-
getter/setter pair
-
onDeviceList
↔ dynamic Function(List<
String> )? -
getter/setter pair
- onLocalOfferUsed ↔ dynamic Function(int, String)?
-
getter/setter pair
- onRemoteAnswer ↔ dynamic Function(String, String)?
-
getter/setter pair
- onRemoteIceCandidate ↔ dynamic Function(String, String, int, String)?
-
getter/setter pair
- onRemoteSdp ↔ dynamic Function(int, String, String)?
-
getter/setter pair
- onRequestConnect ↔ dynamic Function(String)?
-
getter/setter pair
- onResult ↔ dynamic Function(String)?
-
getter/setter pair
- onServerDisconnect ↔ dynamic Function(int, String)?
-
getter/setter pair
- onServerReady ↔ dynamic Function()?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectToDeviceServer(
) → Future< void> -
connectToSignalServer(
) → Future< void> -
disconnect(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
String message) → void -
sendToSignalServer(
String message) → void -
setDeviceId(
String deviceId) → void -
setUserId(
String userId) → void -
setUuid(
String uuid) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- SERVER_ADDR_PORT → const String
- TEST_TOKEN → const String