AIAnalysisExtension class
AI分析扩展 (简化版本) 注意:这是一个可选的扩展,默认不启用
- Inheritance
-
- Object
- LoggerExtension
- AIAnalysisExtension
Constructors
- AIAnalysisExtension({bool enabled = false, bool nasSpecific = false, AnalysisLevel analysisLevel = AnalysisLevel.basic})
Properties
- analysisLevel → AnalysisLevel
-
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- nasSpecific → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
销毁扩展
override
-
initialize(
LoggerEngine engine) → Future< void> -
初始化扩展
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited