NasFileOperationExtension class
NAS文件操作扩展 (简化版本)
- Inheritance
-
- Object
- LoggerExtension
- NasFileOperationExtension
Constructors
Properties
- autoExtractFileInfo → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trackDeviceInfo → bool
-
final
-
trackFileTypes
→ List<
String> -
final
-
trackOperations
→ List<
String> -
final
- trackTransferStatus → bool
-
final
Methods
-
dispose(
) → Future< void> -
销毁扩展
override
-
initialize(
LoggerEngine engine) → Future< void> -
初始化扩展
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
extractNasParameters(
String buttonText, Map< String, dynamic> context) → Map<String, dynamic> - 提取NAS相关参数
-
isNasRelatedButton(
String buttonText) → bool - 检查是否为NAS相关操作