GlobalWidgetInterceptor class
全局Widget拦截器 (增强版本) 自动记录常见的交互组件事件
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
dispose(
) → void - 销毁拦截器
-
logButtonClick(
{required String buttonText, String? currentPage, Map< String, dynamic> ? parameters, String? widgetType}) → void - 手动记录按钮点击事件
-
setup(
LoggerEngine engine) → void - 设置拦截器