NativeCrashPlugin class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isRegistered → bool
-
检查是否已注册
no setter
Static Methods
-
getMemoryInfo(
) → Future< Map< String, dynamic> ?> - 获取内存信息
-
register(
LoggerEngine loggerEngine, LoggerConfig config) → Future< void> - 注册原生崩溃插件
-
testNativeCrash(
) → Future< void> - 测试原生崩溃
-
unregister(
) → void - 注销插件
-
updateSessionId(
String sessionId) → void - 更新会话ID