NativeCrashService class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
检查是否已初始化
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - 销毁资源
-
getNativeMemoryInfo(
) → Future< Map< String, dynamic> ?> - 获取原生内存信息
-
initialize(
LoggerEngine loggerEngine, String sessionId) → Future< void> - 初始化原生崩溃监听
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
testNativeCrash(
) → Future< void> - 测试原生崩溃 (仅用于调试)
-
toString(
) → String -
A string representation of this object.
inherited
-
triggerGC(
) → Future< void> - 触发垃圾回收 (仅Android)
-
updateSessionId(
String sessionId) → void - 更新会话ID
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → NativeCrashService
-
no setter