PageInfoTracker class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(dynamic listener(RouteInfo? current, RouteInfo? previous))
→ void
-
添加路由变化监听器
-
canPop()
→ bool
-
检查是否可以返回
-
clearStack()
→ void
-
清空路由栈
-
dispose()
→ void
-
释放资源
-
exportNavigationHistory()
→ List<Map<String, dynamic>>
-
导出导航历史
-
findPageInStack(String pageName)
→ int
-
查找特定页面在栈中的位置
-
getCurrentPageName()
→ String?
-
获取当前页面名称
-
getCurrentParams()
→ Map<String, dynamic>?
-
获取当前页面参数
-
getCurrentRoute()
→ RouteInfo?
-
获取当前页面信息
-
getCurrentRouteAddress()
→ String?
-
获取当前路由地址
-
getFullRoutePath()
→ List<String>
-
获取完整路由路径
-
getNavigationPath()
→ List<String>
-
获取页面访问路径
-
getPreviousRoute()
→ RouteInfo?
-
获取前一个页面信息
-
getRouteStack()
→ List<RouteInfo>
-
获取路由栈
-
getStackDepth()
→ int
-
获取路由栈深度
-
getStatistics()
→ NavigationStatistics
-
获取导航统计信息
-
healthCheck()
→ Map<String, dynamic>
-
健康检查
-
isCurrentlySystemBack()
→ bool
-
-
markNextPopAsSystemBack()
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
popRoute({bool isSystemBack = false})
→ void
-
记录路由返回
-
pushRoute(String pageName, Map<String, dynamic>? params, {String? routeAddress, bool isTransparent = false, bool isFullDialog = false})
→ void
-
记录新的路由导航
-
removeListener(dynamic listener(RouteInfo? current, RouteInfo? previous))
→ void
-
移除路由变化监听器
-
replaceRoute(String pageName, Map<String, dynamic>? params, {String? routeAddress, bool isTransparent = false, bool isFullDialog = false})
→ void
-
替换当前路由
-
resetStatistics()
→ void
-
重置统计信息
-
toString()
→ String
-
A string representation of this object.
inherited